Configuration used within Crankshaft.
A few notes on the structure of this crate.
- Configuration objects are typically considered immutable and are only able to be constructed programmatically through the use of one of the builders (each configuration object should have an associated builder).
Modules
- backend
- Configuration related to execution backends.
Structs
- Builder
- Use builder syntax to set the inputs and finish with
build(). - Config
- A global configuration object for Crankshaft.
Constants
- ENV_
PREFIX - The prefix for any environment variables that influence the configuration of Crankshaft.
- FILE_
NAME - The file name (sans the extension) used when looking for configuration files for Crankshaft.